from django.db import connection
from .models import QueryProfile

class QueryProfilerMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        response = self.get_response(request)

        if request.path.startswith('/admin/'):  # Only profile queries for the admin section
            for query in connection.queries:
                QueryProfile.objects.create(
                    query=query['sql'],
                    execution_time=query['time']
                )

        return response



from django.contrib import admin
from .models import QueryProfile

@admin.register(QueryProfile)
class QueryProfileAdmin(admin.ModelAdmin):
    list_display = ('query', 'execution_time', 'created_at')
    search_fields = ('query',)



from django.db import models

class QueryProfile(models.Model):
    query = models.TextField()
    execution_time = models.FloatField()
    created_at = models.DateTimeField(auto_now_add=True)

    class Meta:
        ordering = ['-created_at']


from setuptools import setup, find_packages

setup(
    name='django-query-profiler-Georgia',
    version='0.1.0',
    packages=find_packages(),
    include_package_data=True,
    license='MIT License',
    description='A utility to profile SQL queries made by Django ORM and provide insights into their performance',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Anton Polevanov',
    author_email='alulimmerkar@gmail.com',
    url='https://github.com/APolevanov/django-admin-filters',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Framework :: Django',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    install_requires=[
        'Django>=2.2',
    ],
)